==> haskell-system-fileio-0.3.16.4-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-fileio
version:              0.3.16.4
visibility:           public
id:                   system-fileio-0.3.16.4-zh16p89fXpGryJ7x5oR2r
key:                  system-fileio-0.3.16.4-zh16p89fXpGryJ7x5oR2r
license:              MIT
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  1081177c33522e11bd7cf950b89efc62
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-8.10.3/site-local/system-fileio-0.3.16.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/system-fileio-0.3.16.4
hs-libraries:         HSsystem-fileio-0.3.16.4-zh16p89fXpGryJ7x5oR2r
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    system-filepath-0.4.14-3jRmlRAmoRe4W3Q3diL3e3 text-1.2.4.1
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-fileio-0.3.16.4-94-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-fileio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 system-fileio
version:              0.3.16.4
visibility:           public
id:                   system-fileio-0.3.16.4-Fujv3UJwkvfBznLbz5NYY5
key:                  system-fileio-0.3.16.4-Fujv3UJwkvfBznLbz5NYY5
license:              MIT
maintainer:           FP Complete <michael@fpcomplete.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    Consistent filesystem interaction across GHC versions (deprecated)

description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx

category:             System
abi:                  d74f0c4c4c7d19dfc421eb47312ebed1
exposed:              True
exposed-modules:      Filesystem
import-dirs:          /usr/lib/ghc-8.10.3/site-local/system-fileio-0.3.16.4
library-dirs:         /usr/lib/ghc-8.10.3/site-local/system-fileio-0.3.16.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/system-fileio-0.3.16.4
hs-libraries:         HSsystem-fileio-0.3.16.4-Fujv3UJwkvfBznLbz5NYY5
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    system-filepath-0.4.14-AncElNDaNb7DrbfXq2rUst text-1.2.4.1
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-system-fileio/html/system-fileio.haddock

haddock-html:         /usr/share/doc/haskell-system-fileio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
